CommonFinders class
Provides lightweight syntax for getting frequently used component Finders.
This class is instantiated once, as find.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
ancestor(
{required Finder of, required Finder matching, bool matchRoot = false}) → Finder -
Finds components that are ancestors of the
ofparameter and that match thematchingparameter. -
byComponent(
Component component) → Finder - Finds components whose current component is the instance given by the argument.
-
byComponentPredicate(
ComponentPredicate predicate, {String? description}) → Finder -
Finds components using a component
predicate. -
byElementPredicate(
ElementPredicate predicate, {String? description}) → Finder -
Finds components using an element
predicate. -
byElementType(
Type type) → Finder - Finds components by searching for elements with a particular type.
-
byKey(
Key key, {bool skipOffstage = true}) → Finder -
Finds components by searching for one with a particular
Key. -
byType(
Type type) → Finder - Finds components by searching for components with a particular type.
-
componentWithText(
Type componentType, String text) → Finder -
Looks for components that contain a
Component.textdescendant withtextin it. -
descendant(
{required Finder of, required Finder matching, bool matchRoot = false}) → Finder -
Finds components that are descendants of the
ofparameter and that match thematchingparameter. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
tag(
String tag) → Finder -
Finds
Component.elementcomponents with a tag equal to thetagargument. -
text(
String text) → Finder -
Finds
Component.textcomponents containing string equal to thetextargument. -
textContaining(
Pattern pattern) → Finder -
Finds
Component.textcomponents which contain the givenpatternargument. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited